import { useEffect, useRef } from "react";
import LazyImage from "@/components/shared/LazyImage";
// Laikinai neimportuojame motion, kad pagreitintume pradinį užkrovimą (lazy-load vėliau)
// import { motion } from "framer-motion";

const HeroSection = () => {
  const sectionRef = useRef<HTMLElement>(null);

  useEffect(() => {
    // Immediately make elements visible for hero section to avoid flashing
    const fadeElements = document.querySelectorAll("#home .fade-in");
    fadeElements.forEach((el, index) => {
      setTimeout(() => {
        el.classList.add("visible");
      }, index * 200);
    });

    // Only apply intersection observer to non-hero sections or when scrolled down
    if (typeof window !== "undefined" && window.IntersectionObserver) {
      const observer = new IntersectionObserver(
        (entries) => {
          entries.forEach((entry) => {
            if (entry.isIntersecting) {
              const fadeElements = entry.target.querySelectorAll(".fade-in");
              fadeElements.forEach((el, index) => {
                setTimeout(() => {
                  el.classList.add("visible");
                }, index * 200);
              });
            }
          });
        },
        { threshold: 0.1 },
      );

      if (sectionRef.current) {
        observer.observe(sectionRef.current);
      }

      return () => {
        if (sectionRef.current) {
          observer.unobserve(sectionRef.current);
        }
      };
    }
  }, []);

  return (
    <section
      id="home"
      ref={sectionRef}
      className="min-h-screen flex items-center justify-center bg-background pt-24 pb-16"
    >
      <div className="container mx-auto px-6">
        <div className="grid lg:grid-cols-12 gap-12 items-center">
          <div className="lg:col-span-5 lg:col-start-2 order-1 lg:order-1">
            <div className="mb-10 fade-in">
              <h1 className="text-4xl md:text-5xl lg:text-6xl mb-8 font-light leading-tight tracking-tight">
                Vizualiniai pasakojimai, <br />
                kurie įkvepia
              </h1>
              <p className="text-base font-light mb-8 max-w-md">
                Įamžinu tikras emocijas ir idėjas, kad jos gyventų toliau
                vaizduose.
              </p>
              <div className="flex flex-col sm:flex-row gap-4">
                <a
                  href="#portfolio"
                  className="uppercase-wide text-xs px-8 py-4 bg-accent text-white hover:bg-accent/90 transition-colors duration-300"
                >
                  Peržiūrėti darbus
                </a>
                <a
                  href="#contact"
                  className="uppercase-wide text-xs px-8 py-4 border border-accent text-foreground hover:bg-secondary transition-colors duration-300"
                >
                  Susisiekti
                </a>
              </div>
            </div>
          </div>
          <div className="lg:col-span-5 order-2 lg:order-2 fade-in">
            <div className="aspect-[4/5] overflow-hidden rounded-3xl paparazzi-container">
              <div className="paparazzi-flash paparazzi-flash-1"></div>
              <div className="paparazzi-flash paparazzi-flash-2"></div>
              <div className="paparazzi-flash paparazzi-flash-3"></div>
              <div className="paparazzi-flash paparazzi-flash-4"></div>
              <div className="paparazzi-overlay"></div>
              
              {/* Grįžtame prie originalaus vaizdo atributo, kad išsaugotume tinkamą dydžius */}
              <img
                src="https://images.unsplash.com/photo-1554941829-202a0b2403b8?ixlib=rb-1.2.1&auto=format&fit=crop&w=800&q=80"
                srcSet="https://images.unsplash.com/photo-1554941829-202a0b2403b8?ixlib=rb-1.2.1&auto=format&fit=crop&w=400&q=70 400w,
                        https://images.unsplash.com/photo-1554941829-202a0b2403b8?ixlib=rb-1.2.1&auto=format&fit=crop&w=600&q=75 600w,
                        https://images.unsplash.com/photo-1554941829-202a0b2403b8?ixlib=rb-1.2.1&auto=format&fit=crop&w=800&q=80 800w"
                alt="Miglė, fotografė ir videografė iš Vilniaus, minimalistinės fotografijos ir 4K filmavimo paslaugos"
                className="w-full h-full object-cover object-center rounded-3xl"
                loading="eager"
                decoding="async"
                sizes="(max-width: 640px) 95vw, (max-width: 768px) 85vw, 50vw"
                width="800"
                height="1000"
                style={{ contentVisibility: 'auto' }}
              />
            </div>
          </div>
        </div>
      </div>
    </section>
  );
};

export default HeroSection;
